@@ -7,9 +7,10 @@ from sqlalchemy_serializer import SerializerMixin
 import uuid
 
 class Entity(Base, SerializerMixin):
-    
+
     __abstract__  = True
-    serialize_only = ('id', 'date_created','date_modified', 'name', 'description')
+    serialize_only =('date_created','date_modified', 'name', 'description')
+    
     id = Column(Integer, primary_key=True)
     uuid = Column(UUIDType(binary=False), unique=True, nullable=False, default=uuid.uuid4)
     date_created  = Column(DateTime,  default=datetime.datetime.utcnow)
@@ -18,10 +19,15 @@ class Entity(Base, SerializerMixin):
     name = Column(String(200), nullable=True)
     description = Column(Text(), nullable=True)
     is_instance_of = ""
-    
+
     def entity_name(self):
         return self.is_instance_of
     
     def __repr__(self):
         return super().__repr__()
+
+    def to_dict(self):
+        dict = super().to_dict()
+        dict['uuid'] = str(self.uuid)
+        return dict
     
\ No newline at end of file
